metapho.main

Package metapho :: Module main |
[hide private]

# Module main

source code

metapho: an image tagger and viewer.

This is the runnable script, which calls up a GTK-based user interface for viewing images and tagging them.

Classes | [hide private]
| MetaPhoWindow The main controller window for metapho.

Functions | [hide private]
main() | source code

Variables | [hide private]
| __package__ = ``'``metapho``'``